@@ -169,7 +169,9 @@ class Events:
             "content-type": "application/json",
             "FileName": remote_path
         }
-        data = {'file': (file_name, open(file_path, 'rb').read())}
+        f = open(file_path, 'rb')
+        data = {'file': (file_name, f.read())}
+        f.close()
         encode_data = encode_multipart_formdata(data)
         data = encode_data[0]
         header['Content-Type'] = encode_data[1]
